Keywords: Supreme Court of the United States, Supreme Court, Supreme Court of US, Supremecourt, United State Supreme Court, US Supreme Court, U.S. Supreme Court, Court, Opinions, Orders, Opinions relating to orders

Visiting the Court | Touring the Building | Exhibitions

Search: All Documents Docket Advanced Search
Enter Search Text:

Home | Opinions | 2015 Term Opinions Relating to Orders

### 2015 Term Opinions Relating to Orders

The opinions included here are those written by individual Justices to comment on the summary disposition of cases by orders. Such an opinion might, for example, dissent from the denial of certiorari or concur in that denial. The opinions here include those written during October Term 2015 (October 5, 2015, through October 2, 2016). These opinions were posted here on the day of their issuance. They will remain posted until the opinions for the entire Term are published in the bound volumes of the United States Reports. For further information, see Column Header Definitions.

Caution: These electronic opinions may contain computer-generated errors or other deviations from the official paper versions of the opinions. Moreover, the original version of an opinion relating to an order is replaced by a paginated version of the opinion in the preliminary print, and, subsequently, by the final version of the case in a U.S. Reports bound volume. In case of discrepancies between the print and electronic versions of an opinion relating to an order, the print version controls. However, where the electronic version has been designated “revised,” the electronic version controls to the extent that it differs from the print version with regard to the noted revision. In case of discrepancies between the initial print version or electronic version of an opinion relating to an order and any later official version of the opinion—i.e., the preliminary print or bound volume versions—the later version controls.

Date | Docket | Name | Revised | J. | Pt.
--- | --- | --- | --- | --- | ---
1/21/16 | 15-7786 | Brooks v. Alabama |  | SS | 577/1
1/21/16 | 15-7786 | Brooks v. Alabama |  | B | 577/1
12/07/15 | 15-133 | Friedman v. Highland Park |  | T | 577/1
11/30/15 | 15-161 | Rapelje v. Blackston |  | AS | 577/1
11/18/15 | 15-6956 | Holiday v. Stephens |  | SS | 577/1
11/16/15 | 14-1273 | New Hampshire Right to Life v. Department of Health and Human Services |  | T | 577/1
10/29/2015 | 15-6551 | Correll v. Florida |  | SS | 577/1
10/29/2015 | 15-6551 | Correll v. Florida | 10/30/15 | B | 577/1

February 14, 2016 | Version 2014.1
Home | Help | Site Map | Contact Us | About Us | FAQ | Jobs | Links | Building Regulations
Website Policies and Notices | Privacy Policy | USA.GOV
Supreme Court of the United States